@@ -1,5 +1,7 @@
 import click
+import datetime
 import json
+import os
 
 from dateutil.parser import parse
 from pprint import pprint
@@ -167,18 +169,15 @@ def _deploy(project, release_id, environment_id, description, confirm=True):
     headers = ["image ID", "services"]
 
     def _get_service_name(service):
-        if service['response']:
-            return click.style(service['response']["serviceArn"].split("/")[-1], fg="green")
-        else:
-            return click.style("Not found", fg="red")
+        return click.style(service['response']["serviceArn"].split("/")[-1], fg="green")
 
     for image_id, services in sorted(ecs_services.items()):
         service_names = [_get_service_name(service) for service in services]
-        rows.append([image_id, ", ".join(sorted(service_names))])
+        rows.append([image_id, "\n".join(sorted(service_names))])
 
     click.echo("")
     click.echo(click.style("ECS services discovered:\n", fg="yellow", underline=True))
-    click.echo(click.style(tabulate(rows, headers=headers), fg="yellow"))
+    click.echo(tabulate(rows, headers=headers))
 
     if not confirm:
         click.echo("")
@@ -186,23 +185,52 @@ def _deploy(project, release_id, environment_id, description, confirm=True):
 
     result = project.deploy(release_id, environment_id, description)
 
+    # Save the result of the deployment, including things like the ECS deploy IDs.
+    # These can be useful for debugging if something goes wrong.
+    #
+    # We save them on every deploy rather than hiding them behind a --debug flag,
+    # because deploying the same release twice may not have the same results.
+    # e.g. if the second deploy won't re-tag ECR images.
+    out_path = os.path.join(
+        os.environ['HOME'], 'local', 'share', 'weco-deploy',
+        datetime.datetime.now().strftime('deploy_%Y-%m-%d_%H-%M-%S.json')
+    )
+
+    os.makedirs(os.path.dirname(out_path), exist_ok=True)
+    with open(out_path, 'w') as out_file:
+        out_file.write(json.dumps(result, indent=2, sort_keys=True))
+
     click.echo("")
     click.echo(click.style("Deployment Summary", fg="green"))
     click.echo(click.style(f"Requested by: {result['requested_by']}", fg="yellow"))
     click.echo(click.style(f"Date created: {result['date_created']}", fg="yellow"))
+    click.echo(click.style(f"Deploy data:  {out_path}", fg="yellow"))
     click.echo("")
-    for image_id, summary in result['details'].items():
-        click.echo(click.style(f"Summary for {image_id}", fg="bright_yellow"))
-        click.echo(click.style(
-            f"{image_id}: ECR Updated {summary['tag_result']['source']} to {summary['tag_result']['target']}",
-            fg="yellow"
-        ))
 
-        for ecs_deployment in summary['ecs_deployments']:
-            click.echo(click.style(
-                f"{image_id}: ECS Deployed {ecs_deployment['service_arn']} to {ecs_deployment['deployment_id']}",
-                fg="yellow"
-            ))
+    rows = []
+
+    headers = ['image ID', 'summary of changes']
+    for image_id, summary in result['details'].items():
+        if summary['tag_result']['status'] == 'success':
+            ecr_display = 'ECR tag updated'
+        else:
+            ecr_display = ''
+
+        if not summary['ecs_deployments']:
+            ecs_display = ''
+        elif len(summary['ecs_deployments']) == 1:
+            ecs_display = '1 service deployed'
+        else:
+            ecs_display = '%d services deployed' % len(summary['ecs_deployments'])
+
+        if not ecr_display and not ecs_display:
+            rows.append([image_id, '-'])
+        elif not ecr_display:
+            rows.append([image_id, ecs_display])
+        else:
+            rows.append([image_id, ', '.join([ecr_display, ecs_display])])
+
+    click.echo(tabulate(rows, headers=headers))
 
     click.echo("")
     click.echo(click.style(f"Deployed release {release['release_id']} to {env_id}, ({env_name})", fg="bright_green"))
@@ -264,13 +292,11 @@ def _prepare(project, from_label, description):
         rows.append([
             service,
             prev_git_commit,
-            new_git_commit
-            if new_git_commit == prev_git_commit
-            else click.style(new_git_commit, fg="green"),
-            git.log(new_git_commit),
+            "-" if new_git_commit == prev_git_commit else new_git_commit,
+            "-" if new_git_commit == prev_git_commit else git.log(new_git_commit),
         ])
 
-    click.echo(click.style(tabulate(rows, headers=headers), fg="yellow"))
+    click.echo(tabulate(rows, headers=headers))
 
     click.echo("")
     click.echo(click.style(f"Created release {new_release['release_id']}", fg="bright_green"))
