@@ -11,7 +11,7 @@ def create_deployment(environment, user, description):
     }
 
 
-def create_release(project_id, project_name, current_user, release_description, release_images):
+def create_release(project_id, project_name, current_user, description, images):
     release_id = str(uuid.uuid4())
     return {
         "release_id": release_id,
@@ -19,7 +19,7 @@ def create_release(project_id, project_name, current_user, release_description,
         "project_name": project_name,
         "date_created": datetime.datetime.utcnow().isoformat(),
         "requested_by": current_user,
-        "description": release_description,
-        "images": release_images,
+        "description": description,
+        "images": images,
         "deployments": []
     }
