@@ -207,7 +207,7 @@ class Project:
                 services = matched_image.get('services', [])
 
                 available_services = [_get_service(service) for service in services]
-                available_services = [service for service in available_services if service]
+                available_services = [service for service in available_services if service["response"]]
 
             if available_services:
                 matched_services[image_id] = available_services
@@ -343,25 +343,20 @@ class Project:
 
             return ecs_services_deployed[service['response']['serviceArn']]
 
-        for image_id, image_name in release['images'].items():
+        for image_id, image_name in sorted(release['images'].items()):
             tag_result = self._tag_ecr_image(
                 environment_id=environment_id,
                 image_id=image_id,
                 image_name=image_name
             )
 
-            ecs_deployments = []
-            if image_id in matched_services:
-
-                deployments = [_ecs_deploy(service) for service in matched_services.get(image_id)]
-
-                for deployment in deployments:
-                    service_arn = deployment['service_arn']
-                    deployment_id = deployment['deployment_id']
-                    ecs_deployments.append({
-                        'service_arn': service_arn,
-                        'deployment_id': deployment_id
-                    })
+            if tag_result['status'] == 'noop':
+                ecs_deployments = []
+            else:
+                ecs_deployments = [
+                    _ecs_deploy(service)
+                    for service in matched_services.get(image_id, [])
+                ]
 
             deployment_details[image_id] = {
                 'tag_result': tag_result,
